Class: Dev::Sigstore::Fulcio::V2::CA

Inherits:
Object
  • Object
show all
Defined in:
lib/dev/sigstore/fulcio/v2/fulcio_pb.rb

Overview

For Fulcio developers: All features should be designed with HTTP support in mind, since some clients may access this API over HTTP rather than gRPC.

If there’s a feature that you think would negatively impact the HTTP API, open an issue to discuss.

Instance Method Summary collapse

Instance Method Details

#create_signing_certificateObject

*

Returns an X.509 certificate created by the Fulcio certificate authority for the given request parameters

Raises:

  • (NotImplementedError)


48
49
50
# File 'lib/dev/sigstore/fulcio/v2/fulcio_pb.rb', line 48

def create_signing_certificate(...)
  raise(NotImplementedError)
end

#get_configurationObject

*

Returns the configuration of supported OIDC issuers, including the required challenge for each issuer.

Raises:

  • (NotImplementedError)


60
61
62
# File 'lib/dev/sigstore/fulcio/v2/fulcio_pb.rb', line 60

def get_configuration(...)
  raise(NotImplementedError)
end

#get_trust_bundleObject

*

Returns the bundle of certificates that can be used to validate code signing certificates issued by this Fulcio instance

Raises:

  • (NotImplementedError)


54
55
56
# File 'lib/dev/sigstore/fulcio/v2/fulcio_pb.rb', line 54

def get_trust_bundle(...)
  raise(NotImplementedError)
end