Class: Dev::Sigstore::Fulcio::V2::CA
- Inherits:
-
Object
- Object
- Dev::Sigstore::Fulcio::V2::CA
- Defined in:
- lib/dev/sigstore/fulcio/v2/fulcio_pb.rb
Overview
For Fulcio developers: All features should be designed with HTTP support in mind, since some clients may access this API over HTTP rather than gRPC.
If there’s a feature that you think would negatively impact the HTTP API, open an issue to discuss.
Instance Method Summary collapse
-
#create_signing_certificate ⇒ Object
-
Returns an X.509 certificate created by the Fulcio certificate authority for the given request parameters.
-
-
#get_configuration ⇒ Object
-
Returns the configuration of supported OIDC issuers, including the required challenge for each issuer.
-
-
#get_trust_bundle ⇒ Object
-
Returns the bundle of certificates that can be used to validate code signing certificates issued by this Fulcio instance.
-
Instance Method Details
#create_signing_certificate ⇒ Object
*
Returns an X.509 certificate created by the Fulcio certificate authority for the given request parameters
48 49 50 |
# File 'lib/dev/sigstore/fulcio/v2/fulcio_pb.rb', line 48 def create_signing_certificate(...) raise(NotImplementedError) end |
#get_configuration ⇒ Object
*
Returns the configuration of supported OIDC issuers, including the required challenge for each issuer.
60 61 62 |
# File 'lib/dev/sigstore/fulcio/v2/fulcio_pb.rb', line 60 def get_configuration(...) raise(NotImplementedError) end |
#get_trust_bundle ⇒ Object
*
Returns the bundle of certificates that can be used to validate code signing certificates issued by this Fulcio instance
54 55 56 |
# File 'lib/dev/sigstore/fulcio/v2/fulcio_pb.rb', line 54 def get_trust_bundle(...) raise(NotImplementedError) end |